#!/usr/bin/perl -T

use strict;
use warnings;

#*******************************************************************************
# Mentat::Message::Formater::Helper module/class tests
#
# Author:   Jan Mach, jan.mach@cesnet.cz
# Version:  0.1
# Purpose:
#
#*******************************************************************************

use Data::Dumper;
#use Smart::Comments;

use Test::More tests => 13;

# First test if the module correctly compiles
BEGIN {
        use vars qw($TESTED_CLASS);
        $TESTED_CLASS = 'Mentat::Message::Formater::Helper';

        use_ok('Tester');
        use_ok($TESTED_CLASS);
    }

# Debug output explicit ON switch
#Tester::DEBUG_ON();

# Debug output explicit OFF switch
#Tester::DEBUG_OFF();

# User should know, which version is beeing tested (just for sure)
diag("$TESTED_CLASS version: " . $Mentat::Message::Formater::Helper::VERSION) if Tester::D();

# Now attempt to create a class instance and check it
my $instance = $TESTED_CLASS->service();
isa_ok($instance, $TESTED_CLASS);

# View the created instance
diag("Instance dump 01: " . Dumper($instance)) if Tester::D();

is_deeply([$instance->resolve('195.113.144.230', undef)], ['195.113.144.230','www.cesnet.cz'], "Resolve test 01");
is_deeply([$instance->resolve(undef, 'www.cesnet.cz')],   ['195.113.144.230','www.cesnet.cz'], "Resolve test 02");

is_deeply([$instance->resolve('195.113.144.430', undef)], ['195.113.144.430', ''],   "Resolve test 03");
is_deeply([$instance->resolve(undef, 'wwwww.cesnet.cz')],   ['', 'wwwww.cesnet.cz'], "Resolve test 04");

is($instance->anonymize('195.113.144.430'),   '195.113.144.???', "Anonymize test 01");
is($instance->anonymize('195.113.144.430',1), '195.113.144.???', "Anonymize test 02");
is($instance->anonymize('195.113.144.430',2), '195.113.???.???', "Anonymize test 03");
is($instance->anonymize('195.113.144.430',3), '195.???.???.???', "Anonymize test 04");

# Following fails on different character encoding
is($instance->meta('kippo-001', 'label_e'), 'Pokus o neoprávněné připojeni k SSH serveru', "Meta test 01");
is($instance->meta('kippo-001', 'label_s'), 'Stroje na následujících IP adresách se pokusily o neoprávněné připojení k SSH serveru', "Meta test 02");
